[dart/fuzzer] avoid timeouts

Rationale:
Based on monitoring several runs, AOT on SIMARM(64)
simply takes too much time, resulting in sessions
that only have timeouts. Until we fix the runtime,
this CL disables these runs just to avoid wasting
cluster cycles.
Change-Id: I626ab07c64bd097dc8d654dbfc6a8030bc7803d1
Reviewed-on: https://dart-review.googlesource.com/c/78181
Reviewed-by: Alexander Thomas <athom@google.com>
Commit-Queue: Aart Bik <ajcbik@google.com>
diff --git a/runtime/tools/dartfuzz/dartfuzz_test.dart b/runtime/tools/dartfuzz/dartfuzz_test.dart
index 4645b05..2c36548 100644
--- a/runtime/tools/dartfuzz/dartfuzz_test.dart
+++ b/runtime/tools/dartfuzz/dartfuzz_test.dart
@@ -348,10 +348,11 @@
   static String getMode(String mode, String other) {
     // Random when not set.
     if (mode == null || mode == '') {
-      // Pick a mode at random (not JS), different from other.
+      // Pick a mode at random (cluster), different from other.
+      const cluster_modes = 10;
       Random rand = new Random();
       do {
-        mode = modes[rand.nextInt(modes.length - 1)];
+        mode = modes[rand.nextInt(cluster_modes)];
       } while (mode == other);
     }
     // Verify mode.
@@ -375,18 +376,21 @@
 
   // Supported modes.
   static const List<String> modes = [
+    // Cluster options:
     'jit-debug-ia32',
     'jit-debug-x64',
     'jit-debug-arm32',
     'jit-debug-arm64',
-    'aot-debug-x64',
-    'aot-debug-arm64',
     'jit-ia32',
     'jit-x64',
     'jit-arm32',
     'jit-arm64',
+    'aot-debug-x64',
     'aot-x64',
+    // Times out often:
     'aot-arm64',
+    'aot-debug-arm64',
+    // Too many divergences (due to arithmetic):
     'js'
   ];
 }